@@ -1,4 +1,4 @@
-/* Copyright (c) 2006-2015 Jonas Fonseca <jonas.fonseca@gmail.com>
+/* Copyright (c) 2006-2022 Jonas Fonseca <jonas.fonseca@gmail.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -538,6 +538,8 @@ prompt_histfile(void)
 			die("Failed to expand $HOME");
 	} else if (!string_format(path, "%s/tig/history", xdg_data_home))
 		die("Failed to expand $XDG_DATA_HOME");
+	else
+		mkdir(dirname(path), 0777);
 
 	fd = open(path, O_RDWR | O_CREAT | O_APPEND, 0666);
 	if (fd > 0)
@@ -721,7 +723,9 @@ prompt_toggle_option(struct view *view, const char *argv[], const char *prefix,
 /* Define a partial version of success() to format the option name as a suffix to the view name,
  * thereby reducing the arguments needed by success() to only the option value and its format string.
  */
-#define Success(opt_fmt, opt_val) success(":set %s-view-%s = " opt_fmt, view->name, name, opt_val)
+#define Success(opt_fmt, opt_val) *prefix \
+	? success(":set %s-view-%s = " opt_fmt, view->name, name, opt_val) \
+	: success(":set %s = " opt_fmt, name, opt_val)
 
 	char name[SIZEOF_STR];
 
@@ -796,8 +800,10 @@ prompt_toggle_option(struct view *view, const char *argv[], const char *prefix,
 		int i;
 
 		if (argv_size(argv) <= 2) {
-			argv_free(*opt);
-			(*opt)[0] = NULL;
+			if (*opt) {
+				argv_free(*opt);
+				(*opt)[0] = NULL;
+			}
 			return SUCCESS;
 		}
 
@@ -939,7 +945,7 @@ run_prompt_command(struct view *view, const char *argv[])
 
 		/* Trim the leading '!'. */
 		argv[0] = cmd + 1;
-		copied = argv_format(view->env, &next->argv, argv, false, true);
+		copied = argv_format(view->env, &next->argv, argv, argv_flag_file_filter | argv_flag_rev_filter);
 		argv[0] = cmd;
 
 		if (!copied) {
@@ -967,7 +973,7 @@ run_prompt_command(struct view *view, const char *argv[])
 
 		if (argv[1]
 		    && strlen(argv[1]) > 0
-		    && (!argv_format(view->env, &fmt_argv, &argv[1], false, true)
+		    && (!argv_format(view->env, &fmt_argv, &argv[1], argv_flag_file_filter | argv_flag_rev_filter)
 			|| !argv_to_string(fmt_argv, text, sizeof(text), " ")
 			)) {
 			report("Failed to format echo string");
@@ -1102,7 +1108,7 @@ exec_run_request(struct view *view, struct run_request *req)
 
 	if (!argv_to_string(req->argv, cmd, sizeof(cmd), " ")
 	    || !argv_from_string_no_quotes(req_argv, &req_argc, cmd)
-	    || !argv_format(view->env, &argv, req_argv, false, true)
+	    || !argv_format(view->env, &argv, req_argv, argv_flag_file_filter | argv_flag_rev_filter)
 	    || !argv) {
 		report("Failed to format arguments");
 		return REQ_NONE;
